DeviceDescriptor

Struct DeviceDescriptor 

pub struct DeviceDescriptor { /* private fields */ }
A USB device descriptor.

There is one device descriptor provided by a D3XX device. This descriptor holds very basic information about the device, such as its identification, USB version, and function.

Implementations

Source

impl DeviceDescriptor

pub fn serial_number(&self) -> &str

The device serial number.

pub fn manufacturer(&self) -> &str

Human-readable manufacturer name.

pub fn product(&self) -> &str

Human-readable product name.

pub fn vendor_id(&self) -> usize

The vendor ID.

pub fn product_id(&self) -> usize

The product ID.

pub fn usb_version(&self) -> UsbVersion

The USB protocol version (e.g. USB 2.0)

pub fn max_packet_size(&self) -> usize

The maximum size, in bytes, of a packet for an endpoint.

This is typically irrelevant for the user.

pub fn class_codes(&self) -> ClassCodes

Returns a struct containing the interface class codes.

The codes are used to indicate the class, subclass, and protocol.